@@ -4,9 +4,13 @@ from ..functions import log as log_provider
 
 def log(index: str, doc, params=None, headers=None):
 
-    def pass_func():
-        pass
+    def pass_func(func):
+        @wraps(func)
+        def inner(*args, **kwargs):
+            response, status_code = func(*args, **kwargs)
+            return response, status_code
 
+        return inner
     return pass_func
 
     def decorator(func):
